@@ -480,7 +480,8 @@ subgroup <- function(x, tau.preset = NULL, byvar.glmm, ...) {
               seTE.fixed.w = ci.fixed.w$seTE,
               lower.fixed.w = ci.fixed.w$lower,
               upper.fixed.w = ci.fixed.w$upper,
-              zval.fixed.w = ci.fixed.w$z,
+              statistic.fixed.w = ci.fixed.w$statistic,
+              zval.fixed.w = ci.fixed.w$statistic,
               pval.fixed.w = ci.fixed.w$p,
               w.fixed.w = w.fixed.w,
               ##
@@ -488,7 +489,8 @@ subgroup <- function(x, tau.preset = NULL, byvar.glmm, ...) {
               seTE.random.w = ci.random.w$seTE,
               lower.random.w = ci.random.w$lower,
               upper.random.w = ci.random.w$upper,
-              zval.random.w = ci.random.w$z,
+              statistic.random.w = ci.random.w$statistic,
+              zval.random.w = ci.random.w$statistic,
               pval.random.w = ci.random.w$p,
               df.hakn.w = ci.random.w$df,
               w.random.w = w.random.w,
